==> zio-aws-ec2_2.12-5.17.203.2-sources.jar: zio/aws/ec2/model/AssociateIamInstanceProfileResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AssociateIamInstanceProfileResponse(
    iamInstanceProfileAssociation: Optional[
      zio.aws.ec2.model.IamInstanceProfileAssociation
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.AssociateIamInstanceProfileResponse = {
    import AssociateIamInstanceProfileResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.AssociateIamInstanceProfileResponse
      .builder()
      .optionallyWith(
        iamInstanceProfileAssociation.map(value => value.buildAwsValue())
      )(_.iamInstanceProfileAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.AssociateIamInstanceProfileResponse.ReadOnly =
    zio.aws.ec2.model.AssociateIamInstanceProfileResponse.wrap(buildAwsValue())
}
object AssociateIamInstanceProfileResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.AssociateIamInstanceProfileResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.AssociateIamInstanceProfileResponse =
      zio.aws.ec2.model.AssociateIamInstanceProfileResponse(
        iamInstanceProfileAssociation.map(value => value.asEditable)
      )
    def iamInstanceProfileAssociation
        : Optional[zio.aws.ec2.model.IamInstanceProfileAssociation.ReadOnly]
    def getIamInstanceProfileAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.IamInstanceProfileAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "iamInstanceProfileAssociation",
      iamInstanceProfileAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.AssociateIamInstanceProfileResponse
  ) extends zio.aws.ec2.model.AssociateIamInstanceProfileResponse.ReadOnly {
    override val iamInstanceProfileAssociation
        : Optional[zio.aws.ec2.model.IamInstanceProfileAssociation.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.iamInstanceProfileAssociation())
        .map(value =>
          zio.aws.ec2.model.IamInstanceProfileAssociation.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.AssociateIamInstanceProfileResponse
  ): zio.aws.ec2.model.AssociateIamInstanceProfileResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.125.1-sources.jar: zio/aws/ec2/model/AssociateIamInstanceProfileResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AssociateIamInstanceProfileResponse(
    iamInstanceProfileAssociation: Option[
      zio.aws.ec2.model.IamInstanceProfileAssociation
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.AssociateIamInstanceProfileResponse = {
    import AssociateIamInstanceProfileResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.AssociateIamInstanceProfileResponse
      .builder()
      .optionallyWith(
        iamInstanceProfileAssociation.map(value => value.buildAwsValue())
      )(_.iamInstanceProfileAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.AssociateIamInstanceProfileResponse.ReadOnly =
    zio.aws.ec2.model.AssociateIamInstanceProfileResponse.wrap(buildAwsValue())
}
object AssociateIamInstanceProfileResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.AssociateIamInstanceProfileResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.AssociateIamInstanceProfileResponse =
      zio.aws.ec2.model.AssociateIamInstanceProfileResponse(
        iamInstanceProfileAssociation.map(value => value.asEditable)
      )
    def iamInstanceProfileAssociation
        : Option[zio.aws.ec2.model.IamInstanceProfileAssociation.ReadOnly]
    def getIamInstanceProfileAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.IamInstanceProfileAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "iamInstanceProfileAssociation",
      iamInstanceProfileAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.AssociateIamInstanceProfileResponse
  ) extends zio.aws.ec2.model.AssociateIamInstanceProfileResponse.ReadOnly {
    override val iamInstanceProfileAssociation
        : Option[zio.aws.ec2.model.IamInstanceProfileAssociation.ReadOnly] =
      scala
        .Option(impl.iamInstanceProfileAssociation())
        .map(value =>
          zio.aws.ec2.model.IamInstanceProfileAssociation.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.AssociateIamInstanceProfileResponse
  ): zio.aws.ec2.model.AssociateIamInstanceProfileResponse.ReadOnly =
    new Wrapper(impl)
}
